@@ -19,7 +19,6 @@ from geometry.testing import assert_almost_equal
 from pathlib import Path
 from time import time
 from json import load, dump
-from ardupilot_log_reader.reader import Ardupilot
 from flightdata.base.numpy_encoder import NumpyEncoder
 from .ardupilot import flightmodes 
 from flightdata import Origin
@@ -243,6 +242,7 @@ class Flight:
     @staticmethod
     def from_log(log:Union[Ardupilot, str], extra_types: list[str] = None, **kwargs) -> Flight:
         """Constructor from an ardupilot bin file."""
+        from ardupilot_log_reader.reader import Ardupilot
         extra_types = [] if extra_types is None else extra_types
         
         if isinstance(log, str) or isinstance(log, Path):
@@ -447,6 +447,27 @@ class Flight:
                 ))
             return dfs
 
+    @staticmethod
+    def parse_fcj_data(origin: Origin, df: pd.DataFrame):
+        df = Flight.build_cols(
+            time_actual = df['time']/1e6 + int(time()),
+            time_flight = df['time']/1e6,
+            attitude_roll = np.radians(df['r']),
+            attitude_pitch = np.radians(df['p']),
+            attitude_yaw = np.radians(df['yw']),
+            position_N = df['N'],
+            position_E = df['E'],
+            position_D = df['D'],
+            velocity_N = df['VN'],
+            velocity_E = df['VE'],
+            velocity_D = df['VD'],
+            wind_N = df['wN'] if 'wN' in df.columns else None,
+            wind_E = df['wE'] if 'wE' in df.columns else None,
+        )
+
+        return Flight(df.set_index('time_flight', drop=False), None, origin, 'position')
+    
+    
     @staticmethod
     def from_fc_json(fc_json: Union[str, dict, IO]) -> Self:
         
@@ -473,12 +494,24 @@ class Flight:
             wind_N = df['wN'] if 'wN' in df.columns else None,
             wind_E = df['wE'] if 'wE' in df.columns else None,
         )
-        origin = Origin('fcj_origin',GPS(
-            fc_json['parameters']['originLat'], 
-            fc_json['parameters']['originLng'], 
-            fc_json['parameters']['originAlt']
-        ), 0)
-        
+
+        if 'parameters' in fc_json:
+            origin = Origin(
+                'fcj_origin',
+                GPS(
+                    float(fc_json['parameters']['pilotLat']), 
+                    float(fc_json['parameters']['pilotLng']), 
+                    float(fc_json['parameters']['pilotAlt'])
+                ).offset(-Point(
+                    fc_json['parameters']['moveNorth'],
+                    fc_json['parameters']['moveEast'],
+                    0,
+                )), 
+                0
+            )
+        else:
+            origin = Origin('dummy_origin', GPS(0,0,0), -np.pi/2)
+            
         return Flight(df.set_index('time_flight', drop=False), None, origin, 'position')#.remove_time_flutter()
 
     def remove_time_flutter(self):
